//[mahjong-utils](../../../../index.md)/[mahjongutils.hanhu](../../index.md)/[ChildPoint](../index.md)/[Companion](index.md)/[Mangan](-mangan.md)

# Mangan

[common]\
val [Mangan](-mangan.md): [ChildPoint](../index.md)
